/* 
 * Copyright © 2013 Collabora, Ltd.
 * 
 * Permission to use, copy, modify, distribute, and sell this
 * software and its documentation for any purpose is hereby granted
 * without fee, provided that the above copyright notice appear in
 * all copies and that both that copyright notice and this permission
 * notice appear in supporting documentation, and that the name of
 * the copyright holders not be used in advertising or publicity
 * pertaining to distribution of the software without specific,
 * written prior permission.  The copyright holders make no
 * representations about the suitability of this software for any
 * purpose.  It is provided "as is" without express or implied
 * warranty.
 * 
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS, IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 * THIS SOFTWARE.
 */

#ifndef SCALER_CLIENT_PROTOCOL_H
#define SCALER_CLIENT_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include <stddef.h>
#include "wayland-client.h"

struct wl_client;
struct wl_resource;

struct wl_scaler;
struct wl_surface_scaler;

extern const struct wl_interface wl_scaler_interface;
extern const struct wl_interface wl_surface_scaler_interface;

#ifndef WL_SCALER_ERROR_ENUM
#define WL_SCALER_ERROR_ENUM
enum wl_scaler_error {
	WL_SCALER_ERROR_SCALER_EXISTS = 0,
};
#endif /* WL_SCALER_ERROR_ENUM */

#define WL_SCALER_DESTROY	0
#define WL_SCALER_GET_SURFACE_SCALER	1

static inline void
wl_scaler_set_user_data(struct wl_scaler *wl_scaler, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) wl_scaler, user_data);
}

static inline void *
wl_scaler_get_user_data(struct wl_scaler *wl_scaler)
{
	return wl_proxy_get_user_data((struct wl_proxy *) wl_scaler);
}

static inline void
wl_scaler_destroy(struct wl_scaler *wl_scaler)
{
	wl_proxy_marshal((struct wl_proxy *) wl_scaler,
			 WL_SCALER_DESTROY);

	wl_proxy_destroy((struct wl_proxy *) wl_scaler);
}

static inline struct wl_surface_scaler *
wl_scaler_get_surface_scaler(struct wl_scaler *wl_scaler, struct wl_surface *surface)
{
	struct wl_proxy *id;

	id = wl_proxy_marshal_constructor((struct wl_proxy *) wl_scaler,
			 WL_SCALER_GET_SURFACE_SCALER, &wl_surface_scaler_interface, NULL, surface);

	return (struct wl_surface_scaler *) id;
}

#ifndef WL_SURFACE_SCALER_ERROR_ENUM
#define WL_SURFACE_SCALER_ERROR_ENUM
enum wl_surface_scaler_error {
	WL_SURFACE_SCALER_ERROR_BAD_VALUE = 0,
};
#endif /* WL_SURFACE_SCALER_ERROR_ENUM */

#define WL_SURFACE_SCALER_DESTROY	0
#define WL_SURFACE_SCALER_SET	1

static inline void
wl_surface_scaler_set_user_data(struct wl_surface_scaler *wl_surface_scaler, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) wl_surface_scaler, user_data);
}

static inline void *
wl_surface_scaler_get_user_data(struct wl_surface_scaler *wl_surface_scaler)
{
	return wl_proxy_get_user_data((struct wl_proxy *) wl_surface_scaler);
}

static inline void
wl_surface_scaler_destroy(struct wl_surface_scaler *wl_surface_scaler)
{
	wl_proxy_marshal((struct wl_proxy *) wl_surface_scaler,
			 WL_SURFACE_SCALER_DESTROY);

	wl_proxy_destroy((struct wl_proxy *) wl_surface_scaler);
}

static inline void
wl_surface_scaler_set(struct wl_surface_scaler *wl_surface_scaler, wl_fixed_t src_x, wl_fixed_t src_y, wl_fixed_t src_width, wl_fixed_t src_height, int32_t dst_width, int32_t dst_height)
{
	wl_proxy_marshal((struct wl_proxy *) wl_surface_scaler,
			 WL_SURFACE_SCALER_SET, src_x, src_y, src_width, src_height, dst_width, dst_height);
}

#ifdef  __cplusplus
}
#endif

#endif
